<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Devi avviare questo programma come amministratore</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Ripara Boot</translation>
    </message>
    <message>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation type="vanished">MX Ripara Boot è un utility che può servire per reinstallare GRUB sul Registro di Inizializzazione del Disco (MBR) o sul  Registro di Inizializzazione della Partizione root o PBR. Permette di riscrivere il file di configurazione di GRUB, fare il back up e ripristinare MBR o PBR.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Cosa vorresti fare?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Fare il backup dell&apos; MBR o del PBR (solo per legacy boot)</translation>
    </message>
    <message>
        <source>Reinstall GRUB bootloader</source>
        <translation type="vanished">Reinstallare GRUB (il programma che gestisce il boot del computer)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Riparare il file di configurazione di GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Ripristinare MBR o PBR dal backup (solo per legacy boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Selezionare il modo di avvio Boot</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Installare su:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Selezionare la posizione del boot:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>EFI System Partition</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancella tutte le modifiche quando chiudi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>Applica tutti i cambiamenti</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB è in fase d&apos;installazione sulla periferica %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Non si riesce a montare</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation> su /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Non è possibile impostare chroot.
Prego, verifica nuovamente la posizione selezionata.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Il file di configurazione di GRUB (grub.cfg) viene ricostituito.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Backup dell&apos; MBR o del PBR dall&apos;unità %1.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Stai per scrivere il contenuto di</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation>su</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>

Sei sicuro?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Ripristino dell&apos; MBR/PBR da backup sull&apos;unità %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Non si riesce a trovare EFI system partition (ESP) su un qualsiasi disco di sistema. Prego, create un ESP e provate ancora.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Processo ultimato con successo.&lt;p&gt;&lt;b&gt;Vuoi uscire da MX Ripara Boot?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Processo ultimato. Sono incorsi degli errori.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation>Seleziona la posizione di GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation>Seleziona l&apos;elemento da sottoporre a backup</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation>Seleziona l&apos;elemento da ripristinare</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Scegli un nome per il file di backup</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Nessun file è stato scelto</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Scegli il file di backup di MBR o PBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>Informazioni su MX Boot Repair</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programma di MX Linux per la riparazione del boot, di facile uso</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
</TS>
